.. raw:: html
    <head>
        <meta http-equiv='refresh' content='0; URL=./index.html#linking'>
    </head>

# Linking

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

Panel and JS communications <comms/comms>
```
